LUT

Struct LUT 

pub struct LUT {
    pub template: CompactString,
    pub indices: [Vec<f32>; 3],
    pub values: Vec<f32>,
    pub values_unit: f32,
}
A LUT with associated template.

The indices can come from an ad-hoc definition, or inherited from the template. We handle this for you.

The values are NOT normalized with the values_unit.

Fields

template: CompactString

The template name which can be used to look up in parent Lib structs.

indices: [Vec<f32>; 3]

The indices.

Unused axes are empty vectors.

values: Vec<f32>

A flattened values list

values_unit: f32

Unit of values.

currently it is most likely the same as Units::time.